@@ -224,6 +224,8 @@ def find_causes(data, test_function='default', alpha=0.01):
                 cond_set = list(remain_causes)
                 cond_set.remove(can)
                 for cond in combinations(cond_set, l):
+                    data_delete = data[(data[[can] + list(cond)] > -1).all(1)].to_numpy() if factor else data.dropna(
+                        subset=[can] + list(cond))
                     if data_delete.shape[0] > 0:
                         cols = np.asarray(
                             [data_delete.shape[1] - 1] + [varnames.index(can)] + [varnames.index(x) for x in cond])
